/**
 * 获取对应的cookie内容
 * @param cookieName cookie的name
 * @returns cookie的值
 */
export function getCookie(cookieName) {
  var allcookies = document.cookie;
  var cookiePos = allcookies.indexOf(cookieName);
  if (cookiePos !== -1) {
    cookiePos = cookiePos + cookieName.length + 1;
    var cookieEnd = allcookies.indexOf(';', cookiePos);
    if (cookieEnd === -1) {
      cookieEnd = allcookies.length;
    }
    return decodeURIComponent(allcookies.substring(cookiePos, cookieEnd));
  }
  return null;
}
/**
 * 设置修改cookie
 * @param opt 待设置的cookie参数
 */
export function setCookie(opt) {
  var name = opt.name,
    value = opt.value,
    expiredays = opt.expiredays,
    path = opt.path,
    domain = opt.domain;
  var curCookie = "".concat(name, "=").concat(encodeURIComponent(value));
  if (expiredays) {
    var expireDate = new Date();
    expireDate.setDate(expireDate.getDate() + expiredays);
    curCookie += ";expires=".concat(expireDate.toUTCString());
  }
  if (path) {
    curCookie += ";path=".concat(path);
  } else {
    curCookie += ';path=/';
  }
  if (domain) {
    curCookie += ";domain=".concat(domain);
  }
  document.cookie = curCookie;
}

/**
 * 删除一个cookie
 * @param name cookie的name
 */
export var delCookie = function delCookie(name) {
  var exp = new Date();
  exp.setTime(exp.getTime() - 1);
  var cval = getCookie(name);
  if (cval != null) {
    document.cookie = "".concat(name, "=").concat(cval, "; expires=").concat(exp.toUTCString(), "; path=/");
  }
};

/**
 * 删除所有cookie
 */
export var delAllCookie = function delAllCookie() {
  var date = new Date();
  date.setTime(date.getTime() - 10000);
  var keys = document.cookie.match(/[^ =;]+(?==)/g);
  if (keys) {
    keys.forEach(function (name) {
      var expire = date.toUTCString();
      document.cookie = "".concat(name, "=; expire=").concat(expire, "; path=/");
    });
  }
};